-------------------------
-- Namespace stuffages --
-------------------------
local LDB = LibStub:GetLibrary("LibDataBroker-1.1")
local dataobj	= LDB:NewDataObject("nanoPar",
				    {
					    type	= "data source",
					    icon	= "Interface\\Icons\\INV_Shield_36",
					    label	= "nanoPar"
				    }
			    )

local frame	= CreateFrame("Frame")
frame:SetScript("OnEvent",
		function(self, event, ...)
			if self[event] then
				return self[event](self, event, ...)
			end
		end
	)

-------------------
-- Score Updater --
-------------------
local function myIOPscore()
	_, iscore, _, pscore = IOP_GetItemLevels("player")

	if (IOP.Options.pvpValues == 1) then
		return format("%.2f", pscore)
	else
		return format("%.2f", iscore)
	end
end

--------------------
-- Event Handlers --
--------------------
function frame:UNIT_INVENTORY_CHANGED()
	dataobj.text = myIOPscore()
end

function frame:PLAYER_LOGIN()
	LibStub("tekKonfig-AboutPanel").new(nil, "nanoPar")
	dataobj.text = myIOPscore()
	self:Show()
	self:RegisterEvent("UNIT_INVENTORY_CHANGED")
	self:UnregisterEvent("PLAYER_LOGIN")
	self.PLAYER_LOGIN = nil
end

-----------------------
-- Tooltip Functions --
-----------------------
local function GetTipAnchor(frame)
	local x,y = frame:GetCenter()

	if not x or not y then
		return "TOPLEFT", "BOTTOMLEFT"
	end

	local hhalf = (x > UIParent:GetWidth()*2/3) and "RIGHT" or (x < UIParent:GetWidth()/3) and "LEFT" or ""
	local vhalf = (y > UIParent:GetHeight()/2) and "TOP" or "BOTTOM"
	return vhalf..hhalf, frame, (vhalf == "TOP" and "BOTTOM" or "TOP")..hhalf
end


function dataobj.OnLeave()
	GameTooltip:Hide()
end


function dataobj.OnEnter(self)
	GameTooltip:SetOwner(self, "ANCHOR_NONE")
	GameTooltip:SetPoint(GetTipAnchor(self))
	GameTooltip:ClearLines();

	GameTooltip:AddLine("nanoPar");
	GameTooltip:AddLine(IOP_GetItemLevels("player"))
	GameTooltip:AddLine(" ")
	GameTooltip:AddDoubleLine("Click to show recorded scores.", "Shift-Click for options.", nil, nil, nil, nil, nil, nil)
	GameTooltip:AddDoubleLine("Ctrl-Click for your details.", "Alt-Click for Target's details.", nil, nil, nil, nil, nil, nil)
	GameTooltip:Show()
end

function dataobj.OnClick() 
	if IsShiftKeyDown() then 
		ShowUIPanel(InventoryOnParOptionFrame)
	elseif IsControlKeyDown() then
		IOP_ShowPlayerDoll()
	elseif IsAltKeyDown() then
		local name = UnitName("target")
		if name and UnitIsPlayer("target") then
			IOP_UI_ShowTooltip(name)
		end
	else
		ShowUIPanel(InventoryOnParUIFrame)
	end
	PlaySound("GAMEGENERICBUTTONPRESS")
end

--------------------
-- Initialization --
--------------------
if IsLoggedIn() then frame:PLAYER_LOGIN() else frame:RegisterEvent("PLAYER_LOGIN") end
